"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
class IoRedisAdapter {
    constructor(redisClient) {
        this.redisClient = redisClient;
    }
    get(cacheKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.redisClient.get(cacheKey);
            if (!result)
                return null;
            return util_1.parseIfRequired(result);
        });
    }
    set(cacheKey, value, ttl) {
        return __awaiter(this, void 0, void 0, function* () {
            const usableValue = typeof value === 'string' ? value : JSON.stringify(value);
            const ex = ttl ? ['EX', ttl] : [];
            yield this.redisClient.set(cacheKey, usableValue, ex);
        });
    }
    getClientTTL() {
        return 0;
    }
    del(keyOrKeys) {
        return __awaiter(this, void 0, void 0, function* () {
            if (typeof keyOrKeys === 'string') {
                return this.redisClient.del(keyOrKeys);
            }
            if (!keyOrKeys.length)
                return 0;
            return this.redisClient.del(...keyOrKeys);
        });
    }
    keys(pattern) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.redisClient.scan('0', 'MATCH', `*${pattern}*`, 'COUNT', 1000);
            return result ? result[1] : [];
        });
    }
}
exports.IoRedisAdapter = IoRedisAdapter;
